﻿using UnityEngine;
using UnityEditor;
using System.Collections;

// http://docs.unity3d.com/Manual/Example-CreatingaBillboardPlane.html
static class CreatePlaneMesh
{
    [MenuItem("Example/Create Plane Mesh")]
    static void DoMenuItem()
    {
        var path = "Assets/InteriorPlane.asset";

        // Update existing mesh in project
        var mesh = AssetDatabase.LoadAssetAtPath<Mesh>(path);
        if(mesh != null)
        {
            BuildMesh(mesh);
            EditorUtility.SetDirty(mesh);
            return;
        }

        // Create new mesh asset in project
        mesh = new Mesh();
        BuildMesh(mesh);
        AssetDatabase.CreateAsset(mesh, path);
    }

    static void BuildMesh(Mesh mesh)
    {
        mesh.Clear();

        var size = 0.5f;

        var vertices = new Vector3[4];
        vertices[0] = new Vector3(-1, +1, 0) * size;
        vertices[1] = new Vector3(+1, +1, 0) * size;
        vertices[2] = new Vector3(-1, -1, 0) * size;
        vertices[3] = new Vector3(+1, -1, 0) * size;

        mesh.vertices = vertices;


        var tri = new int[6];
        tri[0] = 0;
        tri[1] = 2;
        tri[2] = 1;

        tri[3] = 2;
        tri[4] = 3;
        tri[5] = 1;

        mesh.triangles = tri;


        var normals = new Vector3[4];
        normals[0] = -Vector3.forward;
        normals[1] = -Vector3.forward;
        normals[2] = -Vector3.forward;
        normals[3] = -Vector3.forward;

        mesh.normals = normals;

        // the uvmargin pushes the UV's towards the center of the plane.
        // this makes sure that we have a border in the texture that isn't used
        // by the uv mapping of this mesh.
        var uv = new Vector2[4];
        var uvmargin = 0.25f;
        uv[0] = new Vector2(1 - uvmargin, 1-uvmargin);
        uv[1] = new Vector2(uvmargin, 1-uvmargin);
        uv[2] = new Vector2(1 - uvmargin, uvmargin);
        uv[3] = new Vector2(uvmargin, uvmargin);

        mesh.uv = uv;
    }
}
